Crate log_rs
log_rs
0.1.1
All Items
Crate Items
Structs
Enums
Crate
log_rs
Structs

Logger
A logger that can log messages on different level to different output.
The output of each level can be configured to eventually be same for all, or unique.
Enums

Output
Kind
Identify the three kinds of output supported.